@@ -266,16 +266,16 @@ def main():
                       help="BGP LOCAL PREF attribute (optional)")
     (options, _unused) = parser.parse_args()
 
-    if not(options.operation):
+    if not options.operation:
         parser.error("Need to specify --attach or --detach")
 
-    if not(options.port):
+    if not options.port:
         parser.error("Need to specify --port <localport>")
 
-    if not(options.network_type):
+    if not options.network_type:
         parser.error("Need to specify --network-type")
 
-    if not(options.ip):
+    if not options.ip:
         parser.error("Need to specify --ip")
 
     if (len(options.route_targets) == 0 and
@@ -297,13 +297,13 @@ def main():
     if not re.match('.*/[0-9]+$', options.ip):
         options.ip = options.ip + "/24"
 
-    if not(options.gw_ip):
+    if not options.gw_ip:
         net = netaddr.IPNetwork(options.ip)
         print("using %s as gateway address" % str(net[-2]))
         options.gw_ip = str(net[-2])
 
     if options.vpn_instance_id == DEFAULT_VPN_INSTANCE_ID:
-        options.vpn_instance_id = "%s-%s" % (
+        options.vpn_instance_id = "{}-{}".format(
             options.network_type, options.vpn_instance_id)
 
     if options.port.startswith("netns"):
@@ -325,7 +325,7 @@ def main():
                                                    options.if2vpn,
                                                    options.netns)
 
-        print("Local port: %s (%s)" % (options.port, options.mac))
+        print("Local port: {} ({})".format(options.port, options.mac))
         run_log_command("ip link show %s" % options.port)
 
     local_port = {}
@@ -340,8 +340,8 @@ def main():
 
         # currently our only the MPLS OVS driver for ipvpn requires preplug
         if (options.ovs_preplug and options.network_type == const.IPVPN):
-            print("pre-plugging %s into %s" % (options.port,
-                                               options.bridge))
+            print("pre-plugging {} into {}".format(options.port,
+                                                   options.bridge))
             run_log_command("ovs-vsctl del-port %s %s" %
                             (options.bridge, options.port),
                             raise_on_error=False)
@@ -386,14 +386,14 @@ def main():
                              "one static destination prefix option")
 
     data = {
-        "import_rt":  import_rts,
-        "export_rt":  export_rts,
-        "local_port":  local_port,
-        "vpn_instance_id":  options.vpn_instance_id,
-        "vpn_type":    options.network_type,
-        "gateway_ip":  options.gw_ip,
+        "import_rt": import_rts,
+        "export_rt": export_rts,
+        "local_port": local_port,
+        "vpn_instance_id": options.vpn_instance_id,
+        "vpn_type": options.network_type,
+        "gateway_ip": options.gw_ip,
         "mac_address": options.mac,
-        "ip_address":  options.ip,
+        "ip_address": options.ip,
         "advertise_subnet": options.advertise_subnet,
         "readvertise": readvertise,
         "attract_traffic": attract_traffic,
@@ -407,7 +407,7 @@ def main():
     if options.direction:
         data['direction'] = options.direction
 
-    json_data = jsonutils.dumps(data)
+    json_data = jsonutils.dumps(data).encode('utf-8')
 
     print("request: %s" % json_data)
 
